@@ -2,7 +2,8 @@ import os
 import io
 import tarfile
 import time
-from typing import List, Iterable
+from abc import ABC, abstractmethod
+from typing import List, Iterable, IO, Sequence
 from pathlib import Path
 from contextlib import contextmanager
 from itertools import filterfalse
@@ -44,11 +45,15 @@ def check_tar_contents(path: str):
             )
 
 
-class ArchiveFileBase:
+class ArchiveFileBase(ABC):
     def __init__(self, archive_path: str, content_container):
         self.archive_path = archive_path
         self.content_container = content_container
 
+    @abstractmethod
+    def add_to_tar(self, tar: tarfile.TarFile):
+        pass
+
 
 class ArchiveInMemoryFile(ArchiveFileBase):
     """An ArchiveFileBase whose content_container is a bytes instance"""
@@ -71,7 +76,7 @@ class ArchiveFile(ArchiveFileBase):
             tar.addfile(t, f_opened)
 
 
-def write_tar(content: List[ArchiveFileBase],
+def write_tar(content: Sequence[ArchiveFileBase],
               output_file: str,
               mode="w:gz") -> None:
     """Create a tar.gz archive with files of input file_list.
@@ -121,7 +126,7 @@ def assert_relative(files: Iterable[str]):
             "\n".join(non_relative))
 
 
-def check_extracted(paths: List[str]):
+def check_extracted(paths: Iterable[str]):
     """Tests if all paths in :paths: exist now on the file system"""
     failed = tuple(filterfalse(os.path.exists, paths))
     if failed:
@@ -130,7 +135,7 @@ def check_extracted(paths: List[str]):
 
 
 @contextmanager
-def extract(archive: io.IOBase, *files):
+def extract(archive: IO[bytes], *files):
     with archive as a:
         with tarfile.open(fileobj=a) as tar:
             try:
