@@ -5,7 +5,7 @@ import json
 import re
 import urllib
 from pathlib import Path
-from typing import List, Optional, Tuple, Union
+from typing import List, Optional, Tuple, Union, Type, IO, cast
 import warnings
 from functools import wraps, partial
 
@@ -19,8 +19,10 @@ GPGStore = gpg.GPGStore
 extract_pub_key_ids = gpg.extract_key_id
 get_default_gpg_config_dir = gpg.get_default_gpg_config_dir
 
+ExceptionType = Union[Type[BaseException], Tuple[Type[BaseException], ...]]
 
-def to_user_error(error_types: Union[Exception, Tuple[Exception, ...]]):
+
+def to_user_error(error_types: ExceptionType):
     """A decorator to turn errors of type :error_types: into UserError"""
     def _to_user_error(f):
         @wraps(f)
@@ -33,7 +35,7 @@ def to_user_error(error_types: Union[Exception, Tuple[Exception, ...]]):
     return _to_user_error
 
 
-def to_user_error_gen(error_types: Union[Exception, Tuple[Exception, ...]]):
+def to_user_error_gen(error_types: ExceptionType):
     """A decorator to turn errors of type :error_types: into UserError"""
     def _to_user_error(f):
         @wraps(f)
@@ -111,7 +113,7 @@ def download_keys(fingerprints: List[str], keyserver: str,
         raise KeyserverError(action='download', keyserver=keyserver)
 
 
-def detach_sign_file(src: Union[bytes, io.IOBase], signature_fingerprint: str,
+def detach_sign_file(src: Union[bytes, IO[bytes]], signature_fingerprint: str,
                      passphrase: str, gpg_store: GPGStore) -> bytes:
     """Sign a file with a detached signature"""
     try:
@@ -268,7 +270,7 @@ def assert_key_is_not_revoked(key: gpg.Key):
         raise UserError(f"{key.uids[0]} key has been revoked")
 
 
-def encrypt_and_sign_file(file_object_to_encrypt: io.IOBase,
+def encrypt_and_sign_file(file_object_to_encrypt: IO[bytes],
                           output_file: str,
                           gpg_store: GPGStore,
                           recipients_fingerprint: List[str],
@@ -330,7 +332,7 @@ def decrypt(f: io.FileIO, dest: str, gpg_store: GPGStore,
         try:
             with gpg_store.decrypt(
                     source=stream,
-                    output=fout,
+                    output=cast(io.FileIO, fout),
                     passphrase=passphrase) as fpr_container:
                 sender_fprs = fpr_container.sender_sig_fingerprints
             if not os.path.isfile(dest):
