@@ -119,14 +119,15 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         box = QtWidgets.QGroupBox("Select output name and location")
         # Create fields
         transfer_id = QtWidgets.QLineEdit()
-        transfer_id.setStatusTip("(optional) Transfer ID")
+        transfer_id.setStatusTip("(optional) Data Transfer Request ID")
         transfer_id.setValidator(QtGui.QIntValidator(1, 10**9))
         purpose = QtWidgets.QComboBox(box)
         purpose.setStatusTip("Purpose of the package")
-        purpose.addItems(Purpose.__members__.keys())
-        purpose.setCurrentText(self.app_data.encrypt_purpose.value)
+        purpose.addItems(("",) + tuple(Purpose.__members__.keys()))
+        purpose.setCurrentText("")
+
         offline = QtWidgets.QCheckBox("Offline")
-        offline.setStatusTip("Offline mode: skip transfer_id validation and "
+        offline.setStatusTip("Offline mode: skip DTR ID validation and "
                              "key refreshing.")
         offline.setChecked(self.app_data.encrypt_offline)
         compress = QtWidgets.QCheckBox("Compress inner tarball")
@@ -138,14 +139,16 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             QtGui.QRegExpValidator(QtCore.QRegExp(r"[\w-]*")))
         output_location = PathInput()
         # Add actions
-        transfer_id.textChanged.connect(lambda text:
-            setattr(self.app_data, "encrypt_transfer_id",
-                    int(text) if text else None))
+
+        def on_transfer_id_changed(text):
+            self.app_data.encrypt_transfer_id = int(text) if text else None
+        transfer_id.textChanged.connect(on_transfer_id_changed)
         offline.stateChanged.connect(lambda state:
             setattr(self.app_data, "encrypt_offline",
                     state == QtCore.Qt.Checked))
         purpose.currentTextChanged.connect(lambda text:
-            setattr(self.app_data, "encrypt_purpose", Purpose(text)))
+            setattr(self.app_data, "encrypt_purpose",
+                    None if text == "" else Purpose(text)))
         compress.stateChanged.connect(lambda state:
                                       setattr(self.app_data, "encrypt_compress",
                                               state == QtCore.Qt.Checked))
@@ -156,7 +159,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             partial(setattr, self.app_data, "encrypt_output_location"))
 
         layout = QtWidgets.QFormLayout()
-        layout.addRow("Transfer ID", transfer_id)
+        layout.addRow("DTR ID", transfer_id)
         layout.addRow("", offline)
         layout.addRow("Purpose", purpose)
         layout.addRow("Output suffix", output_suffix)
@@ -200,7 +203,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             logger=(encrypt.logger,),
             sender=self.app_data.encrypt_sender,
             recipient=self.app_data.encrypt_recipients,
-            transfer_id=self.app_data.encrypt_transfer_id,
+            dtr_id=self.app_data.encrypt_transfer_id,
             config=self.app_data.config,
             passphrase=pw,
             output_name=output_path,
