@@ -9,34 +9,35 @@ from ..utils.config import Config
 
 
 class TableModel(QtCore.QAbstractTableModel):
-    def __init__(self, data: Optional[Sequence[Sequence[Any]]] = None,
-                 columns: Optional[Tuple[str]] = None):
+    def __init__(self, data: Sequence[Sequence[Any]] = (),
+                 columns: Optional[Tuple[str, ...]] = None):
         super().__init__()
         self.set_data(data or tuple(tuple()))
-        self.columns = columns or tuple(map(str, range(self.columnCount(None))))
+        self.columns = columns or tuple(
+            map(str, range(self.columnCount())))
 
     @property
-    def columns(self) -> Tuple[str]:
+    def columns(self) -> Tuple[str, ...]:
         return self._columns
 
     @columns.setter
     def columns(self, values: Sequence[str]):
         self._columns = tuple(values)
 
-    def get_data(self) -> Sequence[Sequence[Any]]:
+    def get_data(self) -> Tuple[Sequence[Any], ...]:
         return self._data
 
-    def set_data(self, data: Optional[Sequence[Sequence[Any]]]) -> None:
+    def set_data(self, data: Sequence[Sequence[Any]]) -> None:
         self._data = tuple(sorted(tuple(x) for x in data))
         self.layoutChanged.emit()
         self.dataChanged.emit(
             self.createIndex(0, 0),
-            self.createIndex(self.rowCount(None), self.columnCount(None)))
+            self.createIndex(self.rowCount(), self.columnCount()))
 
-    def rowCount(self, index: QtCore.QModelIndex) -> int:  # pylint: disable=unused-argument
+    def rowCount(self, _parent: QtCore.QModelIndex = QtCore.QModelIndex()) -> int:
         return len(self._data)
 
-    def columnCount(self, index: QtCore.QModelIndex) -> int:  # pylint: disable=unused-argument
+    def columnCount(self, _parent: QtCore.QModelIndex = QtCore.QModelIndex()) -> int:
         return len(self._data) and len(self._data[0])
 
     def headerData(self, section: int, orientation=QtCore.Qt.Horizontal,
@@ -47,15 +48,18 @@ class TableModel(QtCore.QAbstractTableModel):
             return str(section)
         return None
 
-    def data(self, index: QtCore.QModelIndex, role) -> Optional[Hashable]:
+    # Default value Qt.DisplayRole for index is not an int (upstream issue):
+    def data(self, index: QtCore.QModelIndex,  # type: ignore
+             role: int) -> Optional[Hashable]:
         if role == QtCore.Qt.DisplayRole:
             return self._data[index.row()][index.column()]
         return None
 
-    def removeRows(self, row: int, count: int) -> bool:
-        if row > -1 and row + count <= self.rowCount(None):
+    def removeRows(self, row: int, count: int, _parent=QtCore.QModelIndex()) -> bool:
+        if row > -1 and row + count <= self.rowCount():
             self.beginRemoveRows(QtCore.QModelIndex(), row, row + count - 1)
-            self.set_data(self.get_data()[:row] + self.get_data()[row + count:])
+            self.set_data(self.get_data()[:row] +
+                          self.get_data()[row + count:])
             self.endRemoveRows()
             return True
         return False
@@ -63,6 +67,7 @@ class TableModel(QtCore.QAbstractTableModel):
 
 class KeyValueListModel(QtCore.QAbstractListModel):
     """List model extension for key-value objects."""
+
     def __init__(
             self,
             *args,
@@ -76,12 +81,13 @@ class KeyValueListModel(QtCore.QAbstractListModel):
         self._keys = list(self._keyvalues.keys())
         self.layoutChanged.emit()
 
-    def data(self, index, role) -> Optional[Hashable]:
+    # Default value Qt.DisplayRole for index is not an int (upstream issue):
+    def data(self, index, role) -> Optional[Hashable]:   # type: ignore
         if role == QtCore.Qt.DisplayRole:
             return self._keys[index.row()]
         return None
 
-    def rowCount(self, index: QtCore.QModelIndex) -> int:  # pylint: disable=unused-argument
+    def rowCount(self, _parent: QtCore.QModelIndex = QtCore.QModelIndex()) -> int:
         return len(self._keys)
 
     def get_value(self, index: Union[int, QtCore.QModelIndex]) -> Any:
@@ -97,10 +103,10 @@ class AppData:
     config: Config
 
     encrypt_sender: str = ""
-    encrypt_recipients: Tuple[str] = tuple()
+    encrypt_recipients: Tuple[str, ...] = ()
     encrypt_transfer_id: Optional[str] = None
     encrypt_offline: bool = False
-    encrypt_purpose: Purpose = Purpose.PRODUCTION
+    encrypt_purpose: Optional[Purpose] = None
     encrypt_compress: bool = True
     encrypt_output_suffix: str = ""
     encrypt_output_location: Path = field(default_factory=Path.home)
