@@ -29,7 +29,7 @@ def upload(files: List[str],  # nosec (False Positive: pkey_password_encoding)
            pkey_password: Optional[str] = None,
            pkey_password_encoding: str = "utf_8",
            jumphost: Optional[str] = None,
-           progress: ProgressInterface = None):
+           progress: Optional[ProgressInterface] = None):
     if envelope_dir is None:
         envelope_dir = datetime.now().strftime(ENVELOPE_DIR_FMT)
     progress_callback = progress and (lambda x, y: progress.update(x / y))
@@ -42,7 +42,8 @@ def upload(files: List[str],  # nosec (False Positive: pkey_password_encoding)
                              two_factor_callback=two_factor_callback) as sftp:
             sftp.mkdir(str(remote_dir))
             for tar in files:
-                progress.set_label(tar)
+                if progress is not None:
+                    progress.set_label(tar)
                 remotepath = str(remote_dir / Path(tar).name)
                 remotepath_part = remotepath + ".part"
                 status = sftp.put(localpath=os.path.realpath(tar),
