@@ -1,7 +1,7 @@
 import os
 import platform
 import json
-from typing import Dict, Any, Optional
+from typing import Tuple, Dict, Any, Optional
 import tempfile
 
 import dataclasses
@@ -17,7 +17,7 @@ from .. import APP_NAME_SHORT
 
 CONFIG_FILE_NAME = "config.json"
 
-conf_sub_dir_by_os = {
+conf_sub_dir_by_os: Dict[str, Tuple[str, ...]] = {
     "Linux": (".config",),
     "Darwin": (".config",),
     "Windows": ("AppData", "Roaming")
