@@ -4,7 +4,7 @@ from functools import wraps
 import logging
 import logging.handlers
 import warnings
-from typing import Callable
+from typing import Callable, Tuple, Dict, cast, Type, Union
 from pathlib import Path
 
 
@@ -41,9 +41,12 @@ class LogTask:
         return False
 
 
-def exception_to_message(error_list=(), logger=logging):
+ExceptionType = Union[Type[BaseException], Tuple[Type[BaseException], ...]]
+
+
+def exception_to_message(error_types: ExceptionType = (), logger=logging):
     """A function decorator catching the first exception of instance contained
-    in or equal to error_list, occurring while executing the decorated
+    in or equal to error_types, occurring while executing the decorated
     function, logging an error and exiting python.
     """
     def dec(f):
@@ -56,14 +59,27 @@ def exception_to_message(error_list=(), logger=logging):
                     for warning in w:
                         logger.warning(format(warning.message))
                     return r
-            except error_list as e:
+            except error_types as e:
                 logger.error(format(e))
                 on_error(e)
         return wrapped_f
     return dec
 
 
-def create_logger(name, logger_level: int = logging.DEBUG) -> logging:
+class LoggerExt(logging.Logger):
+    """Logger class with additional functionality"""
+
+    def log_task(self, message: str) -> LogTask:
+        """A context manager to log a task which can potentially fail"""
+        return LogTask(message,
+                       ok_logger=self.info,
+                       err_logger=self.error)
+
+
+logging.setLoggerClass(LoggerExt)
+
+
+def create_logger(name, logger_level: int = logging.DEBUG) -> LoggerExt:
     """Instantiate and return a new logger object with the user selected name
      and logging level (e.g. DEBUG, INFO).
 
@@ -74,17 +90,10 @@ def create_logger(name, logger_level: int = logging.DEBUG) -> logging:
     """
     logger = logging.getLogger(name)
     logger.setLevel(logger_level)
-
-    # Define a context manager a function decorator for the logger.
-    logger.log_task = lambda message: LogTask(message,
-                                              ok_logger=logger.info,
-                                              err_logger=logger.error)
-    logger.exception_to_message = lambda error_list=(): \
-        exception_to_message(error_list, logger)
-    return logger
+    return cast(LoggerExt, logger)  # We called logging.setLoggerClass
 
 
-def add_rotating_file_handler_to_logger(logger: logging,
+def add_rotating_file_handler_to_logger(logger: logging.Logger,
                                         log_dir: str,
                                         logger_level: int = logging.DEBUG,
                                         file_max_number: int = 1000,
@@ -102,16 +111,17 @@ def add_rotating_file_handler_to_logger(logger: logging,
     :param file_max_size: maximum size in bytes of an individual logfile.
     """
     # Create log directory if it does not exist yet.
-    log_dir = Path(log_dir)
-    if not log_dir.is_dir():
+    log_dir_path = Path(log_dir)
+    if not log_dir_path.is_dir():
         try:
-            log_dir.mkdir(parents=True)
+            log_dir_path.mkdir(parents=True)
         except PermissionError:
-            logger.error(f'unable to create directory {log_dir.as_posix()}.')
+            logger.error(
+                f'unable to create directory {log_dir_path.as_posix()}.')
 
     # Setup handler for logging info to file. The file logging format adds
     # the data and time at the start of each logged message.
-    log_file = log_dir.joinpath('log')
+    log_file = log_dir_path.joinpath('log')
     file_handler = logging.handlers.RotatingFileHandler(
         filename=log_file.as_posix(),
         mode='a',
@@ -123,7 +133,7 @@ def add_rotating_file_handler_to_logger(logger: logging,
     logger.addHandler(file_handler)
 
 
-def add_stream_handler_to_logger(logger: logging,
+def add_stream_handler_to_logger(logger: logging.Logger,
                                  logger_level: int = logging.INFO) -> None:
     """Add a stream handler to display logging info in console.
 
@@ -142,8 +152,8 @@ def get_default_log_dir() -> str:
     """Returns a string with the default location of the directory where log
     files are stored on the host operating system.
     """
-    default_log_dir_by_os = {'Linux': ('.local/var/log/sett',),
-                             'Darwin': ('.local/var/log/sett',),
-                             'Windows': ('AppData', 'Roaming', 'sett')}
+    default_log_dir_by_os: Dict[str, Tuple[str, ...]] = {'Linux': ('.local/var/log/sett',),
+                                                         'Darwin': ('.local/var/log/sett',),
+                                                         'Windows': ('AppData', 'Roaming', 'sett')}
     return Path.home().joinpath(
         *default_log_dir_by_os[platform.system()]).as_posix()
