@@ -1,13 +1,13 @@
 import os
 import json
 from pathlib import Path
-from typing import List, Optional, Callable
+from typing import List, Optional, Callable, Tuple
 
 from . import workflow
 from ..utils.config import Config
 from ..utils.log import create_logger
 from ..core.archive import write_tar, ArchiveInMemoryFile, ArchiveFile, \
-    METADATA_FILE, METADATA_FILE_SIG, \
+    ArchiveFileBase, METADATA_FILE, METADATA_FILE_SIG, \
     DATA_ARCHIVE, DATA_FILE_ENCRYPTED, CHECKSUM_FILE, \
     CONTENT_FOLDER
 from ..core.filesystem import search_files_recursively, \
@@ -16,7 +16,7 @@ from ..core.crypt import retrieve_keys, encrypt_and_sign_file, \
     detach_sign_file, check_password
 from ..core.checksum import compute_checksum_sha256, write_checksums
 from ..core.error import UserError
-from ..core.metadata import MetaData, alnum_str, Purpose, verify_transfer
+from ..core.metadata import MetaData, alnum_str, Purpose, HexStr1024, HexStr256, verify_transfer
 from ..utils.progress import ProgressInterface, subprogress, \
     progress_file_iter, with_progress
 
@@ -70,14 +70,14 @@ def encrypt(files: List[str],
             *,
             config: Config,
             recipient: List[str],
-            transfer_id: Optional[int] = None,
+            dtr_id: Optional[int] = None,
             sender: Optional[str] = None,
             passphrase: Optional[str] = None,
             output_name: Optional[str] = None,
             dry_run: bool = False,
             offline: bool = False,
             compress: bool = True,
-            purpose: Purpose = Purpose.PRODUCTION,
+            purpose: Optional[Purpose] = None,
             progress: ProgressInterface = None) -> None:
     """Compress and encrypt files and/or directories.
     """
@@ -96,11 +96,11 @@ def encrypt(files: List[str],
     with logger.log_task('Input data check'):
         check_file_read_permission(files_to_encrypt)
         # Retrieve the lowest common directory of all input files/directories.
-        root_dir = os.path.commonpath(Path(x).absolute().parent.as_posix()
-                                      for x in files)
-        if not offline and transfer_id is None:
-            raise UserError("Transfer ID is missing. Use offline mode if you "
-                            "don't require Transfer ID.")
+        root_dir = os.path.commonpath([Path(x).absolute().parent.as_posix()
+                                       for x in files])
+        if not offline and dtr_id is None:
+            raise UserError("DTR (Data Transfer Request) ID is missing. Use offline mode if you "
+                            "don't require DTR ID.")
         if output_name:
             check_arg_value(Path(output_name).name,
                             'output name', output_name_str)
@@ -132,28 +132,32 @@ def encrypt(files: List[str],
                                f'key ID: {key.key_id}'
                                for key in recipients_pub_key]))
 
-        if not offline:
-            try:
-                project_id = verify_transfer(
-                    metadata=MetaData(transfer_id=transfer_id,
-                                      sender=sender_pub_key.fingerprint,
-                                      recipients=[key.fingerprint
-                                                  for key in recipients_pub_key],
-                                      checksum="",
-                                      purpose=purpose),
-                    filename="missing",
-                    portal_endpoint_url=config.dcc_portal_dpkg_endpoint_url)
-                logger.info("Transfer '%s' is a valid for project '%s'",
-                            transfer_id, project_id)
-            except RuntimeError as e:
-                raise UserError(format(e))
+        if dtr_id is not None:
+            if purpose is None:
+                raise UserError("DTR ID specified but `purpose` is missing")
+            if not offline:
+                try:
+                    project_id = verify_transfer(
+                        metadata=MetaData(transfer_id=dtr_id,
+                                          sender=HexStr1024(
+                                              sender_pub_key.fingerprint),
+                                          recipients=[HexStr1024(key.fingerprint)
+                                                      for key in recipients_pub_key],
+                                          checksum=HexStr256("0"*64),
+                                          purpose=purpose),
+                        filename="missing",
+                        portal_endpoint_url=config.dcc_portal_dpkg_endpoint_url)
+                    logger.info("DTR ID '%s' is valid for project '%s'",
+                                dtr_id, project_id)
+                except RuntimeError as e:
+                    raise UserError(format(e))
     if dry_run:
         logger.info('dry run completed successfully.')
         return
 
     # Check if gpg key password is correct
     if config.sign_encrypted_data:
-        check_password(sender_pub_key.fingerprint, passphrase,
+        check_password(sender_pub_key.fingerprint, enforce_passphrase(passphrase),
                        config.gpg_store)
 
     archive_paths = [os.path.join(
@@ -178,17 +182,18 @@ def encrypt(files: List[str],
     with logger.log_task('Compress input data [this may take a while]'):
         # Create a new tar.gz file and add all input files to it.
         tarball_file = os.path.join(config.temp_dir, DATA_ARCHIVE)
+        archives: Tuple[ArchiveFileBase, ...] = ((ArchiveInMemoryFile(CHECKSUM_FILE, checksums),) +
+                                                 tuple(ArchiveFile(a_path, f)
+                                                       for a_path, f in zip(
+                                                     archive_paths, progress_file_iter(
+                                                       files=files_to_encrypt,
+                                                       mode='rb',
+                                                       progress=scaled_progress))
+                                                       ))
         with subprogress(progress,
                          step_completion_increase=0.6) as scaled_progress:
             write_tar(
-                [ArchiveInMemoryFile(CHECKSUM_FILE, checksums)] +
-                [ArchiveFile(a_path, f)
-                 for a_path, f in zip(
-                    archive_paths, progress_file_iter(
-                        files=files_to_encrypt,
-                        mode='rb',
-                        progress=scaled_progress))
-                 ],
+                archives,
                 output_file=tarball_file,
                 mode="w:gz" if compress else "w")
 
@@ -210,7 +215,7 @@ def encrypt(files: List[str],
                                             for key in recipients_pub_key],
                     signature_fingerprint=sender_pub_key.fingerprint if
                     config.sign_encrypted_data else None,
-                    passphrase=passphrase if config.sign_encrypted_data
+                    passphrase=enforce_passphrase(passphrase) if config.sign_encrypted_data
                     else None,
                     always_trust=config.always_trust_recipient_key)
         finally:
@@ -232,19 +237,19 @@ def encrypt(files: List[str],
             # Create a dictionary with all the info we want to store in the .json
             # file, then pass this dictionary to json.dump that will convert it to
             # a json file. Use indent=4 to make the output file easier on the eye.
-            metadata = MetaData(transfer_id=transfer_id,
-                                sender=sender_pub_key.fingerprint,
-                                recipients=[key.fingerprint
+            metadata = MetaData(transfer_id=dtr_id,
+                                sender=HexStr1024(sender_pub_key.fingerprint),
+                                recipients=[HexStr1024(key.fingerprint)
                                             for key in recipients_pub_key],
                                 purpose=purpose,
-                                checksum=encrypted_checksum,
+                                checksum=HexStr256(encrypted_checksum),
                                 compression_algorithm="gzip" if compress else "")
             metadata_bytes = json.dumps(
                 MetaData.asdict(metadata), indent=4).encode()
             metadata_signature_bytes = b""
             if config.sign_encrypted_data:
                 metadata_signature_bytes = detach_sign_file(
-                    metadata_bytes, sender_pub_key.fingerprint, passphrase,
+                    metadata_bytes, sender_pub_key.fingerprint, enforce_passphrase(passphrase),
                     config.gpg_store)
 
         with logger.log_task('Generate final tarball'):
@@ -256,18 +261,26 @@ def encrypt(files: List[str],
                                (METADATA_FILE_SIG, metadata_signature_bytes))
             with subprogress(progress,
                              step_completion_increase=0.05) as scaled_progress:
-                write_tar(
-                    [ArchiveInMemoryFile(path, content)
-                     for path, content in in_memory_files] +
-                    [ArchiveFile(os.path.relpath(f.name, start=config.temp_dir), f)
-                     for f in progress_file_iter(
-                        files=[encrypted_file],
+                archives = (
+                    tuple(ArchiveInMemoryFile(path, content)
+                          for path, content in in_memory_files) +
+                    tuple(ArchiveFile(os.path.relpath(f.name, start=config.temp_dir), f)
+                          for f in progress_file_iter(
+                        files=[
+                            encrypted_file],
                         mode='rb',
                         progress=scaled_progress)
-                     ],
+                    ))
+                write_tar(
+                    archives,
                     output_file=output_name,
                     mode="w")
     finally:
         delete_files(encrypted_file)
 
     logger.info('Completed data encryption: %s', output_name)
+
+def enforce_passphrase(passphrase: Optional[str]) -> str:
+    if passphrase is None:
+        raise ValueError("No password given")
+    return passphrase
