@@ -1,4 +1,4 @@
-import typing
+from typing import List, Tuple, Callable, Dict
 import json
 
 from . import workflow
@@ -6,7 +6,7 @@ from ..utils.config import Config
 from ..utils.log import create_logger
 from ..utils.progress import ProgressInterface
 from ..core.crypt import get_recipient_email, extract_pub_key_ids, \
-    validated_keys_by_ids
+    validated_keys_by_ids, gpg
 from ..core.archive import check_tar, extract, METADATA_FILE, DATA_FILE_ENCRYPTED
 from ..core.metadata import load_metadata, verify_transfer
 from ..core.error import UserError
@@ -17,10 +17,10 @@ logger = create_logger(__name__)
 
 
 @workflow(logger, (UserError, FileNotFoundError))
-def transfer(files: typing.List[str],
+def transfer(files: List[str],
              *,
              protocol,
-             two_factor_callback: typing.Callable,
+             two_factor_callback: Callable,
              protocol_args: dict,
              config: Config,
              dry_run: bool = False,
@@ -37,7 +37,7 @@ def transfer(files: typing.List[str],
         for tar in files:
             check_tar(tar)
 
-    files_by_recipient = {}
+    files_by_recipient: Dict[Tuple[gpg.Key, ...], List[str]] = {}
     with logger.log_task("Extracting destination for each file to transfer"):
         for tar in files:
             logger.info("\t-> %s", tar)
